# SoccerXComm

SoccerXComm is a Python library for communication between SoccerX platform and the agents.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install.

```shell
pip install soccerxcomm
```

## Usage

See the [documentation](https://moshumanoid.github.io/SoccerXComm/) for more information.

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License

[MIT License](https://choosealicense.com/licenses/mit/)
